==> eclipse_2.1.3.orig.tar.gz: plugins/org.eclipse.help.ui/src/org/eclipse/help/ui/internal/util/ErrorUtil.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.help.ui.internal.util;
import org.eclipse.help.internal.*;
import org.eclipse.help.internal.util.*;
import org.eclipse.help.ui.internal.*;
import org.eclipse.jface.dialogs.*;
import org.eclipse.swt.widgets.*;
import org.eclipse.ui.*;
/**
 * Utiliy class for common error displaying tasks.
 */
public class ErrorUtil implements IErrorUtil {
	public void displayError(String msg) {
		displayErrorDialog(msg);
	}

	public void displayError(final String msg, Thread uiThread) {
		try {
			Display.findDisplay(uiThread).asyncExec(new Runnable() {
				public void run() {
					displayErrorDialog(msg);
				}
			});
		} catch (Exception e2) {
		}
	}
	/**
	 * Immidiately displays error dialog with a given string,
	 * also logs the error using Logger.logError().
	 * msg error message to display and log.
	 */
	public static void displayErrorDialog(String msg) {
		String title = WorkbenchResources.getString("Help_Error");
		IWorkbenchWindow workbenchWindow = getActiveWorkbenchWindow();
		Shell shell;
		if (workbenchWindow != null) {
			shell = workbenchWindow.getShell();
		} else {
			shell = new Shell();
		}
		MessageDialog.openError(shell, title, msg);
		WorkbenchHelpPlugin.logError(msg, null);
	}
	/**
	 * Immidiately displays error dialog with a given string,
	 * also logs the error using Logger.logError().
	 * msg error message to display and log.
	 * ex  the exception to be passed to Logger.logError()
	 */
	public static void displayErrorDialog(String msg, Throwable ex) {
		String title = WorkbenchResources.getString("Help_Error");
		IWorkbenchWindow workbenchWindow = getActiveWorkbenchWindow();
		Shell shell;
		if (workbenchWindow != null) {
			shell = workbenchWindow.getShell();
		} else {
			shell = new Shell();
		}
		MessageDialog.openError(shell, title, msg);
		WorkbenchHelpPlugin.logError(msg, ex);
	}
	/**
	 * Immidiately displays an Information dialog with a given string,
	 * also logs the info using Logger.logInfo().
	 * msg error message to display and log.
	 */
	public static void displayInfoDialog(String msg) {
		String title = WorkbenchResources.getString("Help_Info");
		IWorkbenchWindow workbenchWindow = getActiveWorkbenchWindow();
		Shell shell;
		if (workbenchWindow != null) {
			shell = workbenchWindow.getShell();
		} else {
			shell = new Shell();
		}
		MessageDialog.openInformation(shell, title, msg);
		if (HelpPlugin.DEBUG) {
			System.out.println(msg);
		}
	}
	/**
	 * Immidiately displays a Question dialog with a given string (question).
	 * No logging is done.
	 * returns which button(Yes/No) was pressed by user
	 */
	public static boolean displayQuestionDialog(String msg) {
		String title = WorkbenchResources.getString("Help_Question");
		IWorkbenchWindow workbenchWindow = getActiveWorkbenchWindow();
		Shell shell;
		if (workbenchWindow != null) {
			shell = workbenchWindow.getShell();
		} else {
			shell = new Shell();
		}
		return MessageDialog.openQuestion(shell, title, msg);
	}
	/**
	 * Display all errors in the Help Status object. If no errors occurred,
	 * or if errors have already been displayed, return.
	 */
	public static void displayStatus() {
		// show error dialog box if errors have occurred
		if (RuntimeHelpStatus.getInstance().errorsExist()) {
			String title = WorkbenchResources.getString("Help_Error");
			String msg = WorkbenchResources.getString("WE005");
			//Errors encountered while displaying help.
			String errorMessage = RuntimeHelpStatus.getInstance().toString();
			Shell parent = getActiveWorkbenchWindow().getShell();
			RuntimeErrorDialog.open(parent, title, msg, errorMessage);
			// for now, reset status object so that errors are not
			// displayed again.
			RuntimeHelpStatus.getInstance().reset();
		}
		return;
	}
	protected static IWorkbenchWindow getActiveWorkbenchWindow() {
		return PlatformUI.getWorkbench().getActiveWorkbenchWindow();
	}
}

==> eclipse_3.1.2.orig.tar.gz: plugins/org.eclipse.help.ui/src/org/eclipse/help/ui/internal/util/ErrorUtil.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.help.ui.internal.util;

import org.eclipse.help.internal.HelpPlugin;
import org.eclipse.help.internal.base.util.IErrorUtil;
import org.eclipse.help.ui.internal.Messages;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;

/**
 * Utiliy class for common error displaying tasks.
 */
public class ErrorUtil implements IErrorUtil {
	public void displayError(String msg) {
		displayErrorDialog(msg);
	}

	public void displayError(final String msg, Thread uiThread) {
		try {
			Display.findDisplay(uiThread).asyncExec(new Runnable() {
				public void run() {
					displayErrorDialog(msg);
				}
			});
		} catch (Exception e2) {
		}
	}

	/**
	 * Immidiately displays error dialog with a given string
	 * 
	 * @param msg
	 *            error message to display and log.
	 */
	public static void displayErrorDialog(String msg) {
		String title = Messages.Help_Error; 
		IWorkbenchWindow workbenchWindow = getActiveWorkbenchWindow();
		Shell shell;
		if (workbenchWindow != null) {
			shell = workbenchWindow.getShell();
		} else {
			shell = new Shell();
		}
		MessageDialog.openError(shell, title, msg);
	}

	/**
	 * Immidiately displays an Information dialog with a given string
	 * 
	 * @param msg
	 *            error message to display.
	 */
	public static void displayInfoDialog(String msg) {
		String title = Messages.Help_Info; 
		IWorkbenchWindow workbenchWindow = getActiveWorkbenchWindow();
		Shell shell;
		if (workbenchWindow != null) {
			shell = workbenchWindow.getShell();
		} else {
			shell = new Shell();
		}
		MessageDialog.openInformation(shell, title, msg);
		if (HelpPlugin.DEBUG) {
			System.out.println(msg);
		}
	}

	/**
	 * Immidiately displays a Question dialog with a given string (question).
	 * 
	 * @return which button(Yes/No) was pressed by user
	 */
	public static boolean displayQuestionDialog(String msg) {
		String title = Messages.Help_Question; 
		IWorkbenchWindow workbenchWindow = getActiveWorkbenchWindow();
		Shell shell;
		if (workbenchWindow != null) {
			shell = workbenchWindow.getShell();
		} else {
			shell = new Shell();
		}
		return MessageDialog.openQuestion(shell, title, msg);
	}

	protected static IWorkbenchWindow getActiveWorkbenchWindow() {
		return PlatformUI.getWorkbench().getActiveWorkbenchWindow();
	}
}
